.. _index:


.. image:: _static/PyCorrFit_logo_dark.png

|

Welcome to the documentation of PyCorrFit (version |release|), a data analysis software for
fluorescence correlation spectroscopy (FCS).

Documentation
=============

.. toctree::
   :maxdepth: 2

   sec_about
   sec_gallery
   sec_getting_started
   sec_contribute

.. toctree::
   :maxdepth: 1

   sec_changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
